pub struct PubSubHandler<T, S = Noop>where
    T: PubSubMetadata,
    S: Middleware<T>,{ /* private fields */ }
Publish-Subscribe extension of IoHandler.

Implementations

source

impl<T, S> PubSubHandler<T, S>where T: PubSubMetadata, S: Middleware<T>,

source

pub fn new(handler: MetaIoHandler<T, S>) -> PubSubHandler<T, S>

Creates new PubSubHandler

source

pub fn add_subscription<F, G>( &mut self, notification: &str, subscribe: (&str, F), unsubscribe: (&str, G) )where F: SubscribeRpcMethod<T>, G: UnsubscribeRpcMethod<T>,

Adds new subscription.

Methods from Deref<Target = MetaIoHandler<T, S>>

source

pub fn add_alias(&mut self, alias: &str, other: &str)

Adds an alias to a method.

source

pub fn add_sync_method<F>(&mut self, name: &str, method: F)where F: RpcMethodSync,

Adds new supported synchronous method.

A backward-compatible wrapper.

source

pub fn add_method<F>(&mut self, name: &str, method: F)where F: RpcMethodSimple,

Adds new supported asynchronous method.

source

pub fn add_notification<F>(&mut self, name: &str, notification: F)where F: RpcNotificationSimple,

Adds new supported notification

source

pub fn add_method_with_meta<F>(&mut self, name: &str, method: F)where F: RpcMethod<T>,

Adds new supported asynchronous method with metadata support.

source

pub fn add_notification_with_meta<F>(&mut self, name: &str, notification: F)where F: RpcNotification<T>,

Adds new supported notification with metadata support.

source

pub fn extend_with<F>(&mut self, methods: F)where F: IntoIterator<Item = (String, RemoteProcedure<T>)>,

Extend this MetaIoHandler with methods defined elsewhere.

source

pub fn handle_request_sync(&self, request: &str, meta: T) -> Option<String>

Handle given request synchronously - will block until response is available. If you have any asynchronous methods in your RPC it is much wiser to use handle_request instead and deal with asynchronous requests in a non-blocking fashion.

source

pub fn handle_request( &self, request: &str, meta: T ) -> Map<Either<Ready<Option<Response>>, Either<<S as Middleware<T>>::Future, Either<Map<Either<<S as Middleware<T>>::CallFuture, Either<Pin<Box<dyn Future<Output = Option<Output>> + Send + 'static, Global>>, Ready<Option<Output>>>>, fn(_: Option<Output>) -> Option<Response>>, Map<JoinAll<Either<<S as Middleware<T>>::CallFuture, Either<Pin<Box<dyn Future<Output = Option<Output>> + Send + 'static, Global>>, Ready<Option<Output>>>>>, fn(_: Vec<Option<Output>, Global>) -> Option<Response>>>>>, fn(_: Option<Response>) -> Option<String>>

Handle given request asynchronously.

source

pub fn handle_rpc_request( &self, request: Request, meta: T ) -> Either<<S as Middleware<T>>::Future, Either<Map<Either<<S as Middleware<T>>::CallFuture, Either<Pin<Box<dyn Future<Output = Option<Output>> + Send + 'static, Global>>, Ready<Option<Output>>>>, fn(_: Option<Output>) -> Option<Response>>, Map<JoinAll<Either<<S as Middleware<T>>::CallFuture, Either<Pin<Box<dyn Future<Output = Option<Output>> + Send + 'static, Global>>, Ready<Option<Output>>>>>, fn(_: Vec<Option<Output>, Global>) -> Option<Response>>>>

Handle deserialized RPC request.

source

pub fn handle_call( &self, call: Call, meta: T ) -> Either<<S as Middleware<T>>::CallFuture, Either<Pin<Box<dyn Future<Output = Option<Output>> + Send + 'static, Global>>, Ready<Option<Output>>>>

Handle single call asynchronously.

source

pub fn iter(&self) -> impl Iterator<Item = (&String, &RemoteProcedure<T>)>

Returns an iterator visiting all methods in arbitrary order.