Traits and implementations of mono-transport and multi-transport servers.
Structs
- Multiple
Transports Server - A JSON-RPC server that supports using multiple transports at once.
- Single
Transport Server - A simple JSON-RPC server that only uses one transport.
Enums
- Server
Error - Enumerates all the different errors that a
Servercan get into.
Traits
- Server
- Trait defining a JSON-RPC server.
Type Aliases
- Witty
Mono Server - A convenient type alias for a single transport server that supports PubSub.
- Witty
Multi Server - A convenient type alias for a multiple transports server that supports PubSub.