Module witty_jsonrpc::server

source ·
Traits and implementations of mono-transport and multi-transport servers.

Structs

Enums

  • Enumerates all the different errors that a Server can get into.

Traits

  • Trait defining a JSON-RPC server.

Type Definitions

  • A convenient type alias for a single transport server that supports PubSub.
  • A convenient type alias for a multiple transports server that supports PubSub.