Module witty_jsonrpc::server
source · Expand description
Traits and implementations of mono-transport and multi-transport servers.
Structs
- A JSON-RPC server that supports using multiple transports at once.
- A simple JSON-RPC server that only uses one transport.
Enums
- Enumerates all the different errors that a
Servercan get into.
Traits
- Trait defining a JSON-RPC server.
Type Definitions
- A convenient type alias for a single transport server that supports PubSub.
- A convenient type alias for a multiple transports server that supports PubSub.